from Products.TinyMCE.utility import form_adapter
from Products.TinyMCE.tests.base import FunctionalTestCase


class BrowserTestCase(FunctionalTestCase):

    def setUp(self):
        super(BrowserTestCase, self).setUp()
        self.image = self.portal.invokeFactory('Image', id='image')
        self.document = self.portal.invokeFactory('Document', id='document')

    def test_url(self):
        # We get the url by specifying the uid of the document.
        self.portal.REQUEST['uid'] = self.portal[self.document].UID()
        output = self.portal.restrictedTraverse('/plone/portal_tinymce/@@tinymce-getpathbyuid')()
        self.assertEqual(output, 'http://nohost/plone/document')

        # If we don't specify the uid we get an empty string.
        self.portal.REQUEST['uid'] = None
        output = self.portal.restrictedTraverse('/plone/portal_tinymce/@@tinymce-getpathbyuid')()
        self.assertEqual(output, '')

        self.portal.REQUEST['uid'] = 'asd'
        # If we specify a non existing uid we should get an empty string.
        output = self.portal.restrictedTraverse('/plone/portal_tinymce/@@tinymce-getpathbyuid')()
        self.assertEqual(output, '')

    def test_getstyle(self):
        # This browserview will return all the stylesheets used. Let's call the
        # browser view.
        output = self.portal.restrictedTraverse('/plone/portal_tinymce/@@tinymce-getstyle')()
        self.assertRegexpMatches(output, '<!-- @import url\(.+portal_css.+\); -->')

    def test_controlpanel(self):
        # Open the TinyMCE control panel.
        self.portal.restrictedTraverse('/plone/portal_tinymce/@@tinymce-controlpanel')()

    def test_jsonlinkablefolderlisting(self):
        # We can call the linkable folder listing browserview on the site root to get a
        # list of linkable items.
        output = self.portal.restrictedTraverse('/plone/@@tinymce-jsonlinkablefolderlisting')(False, 'http://nohost/plone/')
        self.assertIn('"id": "document"', output)

    def test_jsonimagefolderlisting(self):
        # Now we can get a listing of the images and check if our image is there.e/'})
        output = self.portal.restrictedTraverse('/plone/@@tinymce-jsonimagefolderlisting')(False, 'http://nohost/plone/')
        self.assertIn('"id": "image"', output)

    def test_jsonlinkablesearch(self):
        # If we want to search for a linkable item we can call the json linkable search
        # browser view and specify a searchtext. Let's find our document.
        output = self.portal.restrictedTraverse('/plone/@@tinymce-jsonlinkablesearch')('Document')
        self.assertIn('"id": "document"', output)

    def test_jsonimagesearch(self):
        # The images have a similar search method. Let's find our image.
        output = self.portal.restrictedTraverse('/plone/@@tinymce-jsonimagesearch')('Image')
        self.assertIn('"id": "image"', output)

    def test_jsondetails(self):
        # When we call the json details view on a document we will get the details of
        # the specific item.
        output = self.portal.restrictedTraverse('/plone/document/@@tinymce-jsondetails')()
        self.assertIn('document', output)

    def test_save(self):
        # Let's call the save method to store some content in the document we created.
        self.portal.restrictedTraverse('/plone/document/@@tinymce-save')('test', 'text')
        self.assertEqual(self.portal[self.document].getText(), 'test')

    def test_configuration(self):
        document_jsonconfig_url = '/plone/document/@@tinymce-jsonconfiguration'
        output = self.portal.restrictedTraverse(document_jsonconfig_url)('text')
        self.assertIn('buttons', output)

        # If we configure directivity to 'auto', the directivity is set depending
        # on the content language.
        utility = form_adapter(self.portal)
        utility.directionality = 'auto'
        doc = self.portal[self.document]
        self.assertEqual(doc.Language(), 'en')
        output = self.portal.restrictedTraverse(document_jsonconfig_url)('text')
        self.assertIn('"directionality": "ltr"', output)
        doc.setLanguage('ar')
        output = self.portal.restrictedTraverse(document_jsonconfig_url)('text')
        self.assertIn('"directionality": "rtl"', output)

        # TODO: upload



# BBB

from Products.MimetypesRegistry.interfaces import IClassifier
from Products.MimetypesRegistry.MimeTypeItem import MimeTypeItem
from Products.MimetypesRegistry.common import MimeTypeException
from Products.MimetypesRegistry.interfaces import IMimetype
from zope.interface import implements
from types import InstanceType


class text_tinymce_output_html(MimeTypeItem):
    __name__ = "TinyMCE Output HTML"
    mimetypes = ('text/x-tinymce-output-html',)
    binary = 0



from Products.GenericSetup.utils import exportObjects
from Products.GenericSetup.utils import importObjects
from Products.GenericSetup.utils import XMLAdapterBase

from Products.CMFCore.utils import getToolByName


class TinyMCESettingsXMLAdapter(XMLAdapterBase):
    name = 'tinymce'
    _LOGGER_ID = 'portal_tinymce'

    attributes = {
        'layout': {
            'resizing': {'type': 'Bool', 'default': True},
            'autoresize': {'type': 'Bool', 'default': False},
            'editor_width': {'type': 'Text', 'default': u'100%'},
            'editor_height': {'type': 'Text', 'default': u'400'},
            'directionality': {'type': 'Text', 'default': u'ltr'},
            'contextmenu': {'type': 'Bool', 'default': True},
            'content_css': {'type': 'Text', 'default': u''},
            'styles': {'type': 'List', 'default': u'Heading|h2\nSubheading|h3\nLiteral|pre\nDiscreet|p|discreet\nPull-quote|div|pullquote\nCall-out|p|callout\nHighlight|span|visualHighlight\nOdd row|tr|odd\nEven row|tr|even\nHeading cell|th|\nPage break (print only)|div|pageBreak\nClear floats|div|visualClear'},
            'tablestyles': {'type': 'List', 'default': u'Subdued grid|plain\nInvisible grid|invisible\nFancy listing|listing\nFancy grid listing|grid listing\nFancy vertical listing|vertical listing'},
        },
        'toolbar': {
            'toolbar_width': {'type': 'Text', 'default': u'440'},
            'toolbar_external': {'type': 'Bool', 'default': False},
            'toolbar_save': {'type': 'Bool', 'default': True},
            'toolbar_cut': {'type': 'Bool', 'default': False},
            'toolbar_copy': {'type': 'Bool', 'default': False},
            'toolbar_paste': {'type': 'Bool', 'default': False},
            'toolbar_pastetext': {'type': 'Bool', 'default': False},
            'toolbar_pasteword': {'type': 'Bool', 'default': False},
            'toolbar_undo': {'type': 'Bool', 'default': False},
            'toolbar_redo': {'type': 'Bool', 'default': False},
            'toolbar_search': {'type': 'Bool', 'default': False},
            'toolbar_replace': {'type': 'Bool', 'default': False},
            'toolbar_style': {'type': 'Bool', 'default': True},
            'toolbar_bold': {'type': 'Bool', 'default': True},
            'toolbar_italic': {'type': 'Bool', 'default': True},
            'toolbar_underline': {'type': 'Bool', 'default': False},
            'toolbar_strikethrough': {'type': 'Bool', 'default': False},
            'toolbar_sub': {'type': 'Bool', 'default': False},
            'toolbar_sup': {'type': 'Bool', 'default': False},
            'toolbar_forecolor': {'type': 'Bool', 'default': False},
            'toolbar_backcolor': {'type': 'Bool', 'default': False},
            'toolbar_justifyleft': {'type': 'Bool', 'default': True},
            'toolbar_justifycenter': {'type': 'Bool', 'default': True},
            'toolbar_justifyright': {'type': 'Bool', 'default': True},
            'toolbar_justifyfull': {'type': 'Bool', 'default': True},
            'toolbar_bullist': {'type': 'Bool', 'default': True},
            'toolbar_numlist': {'type': 'Bool', 'default': True},
            'toolbar_definitionlist': {'type': 'Bool', 'default': True},
            'toolbar_outdent': {'type': 'Bool', 'default': True},
            'toolbar_indent': {'type': 'Bool', 'default': True},
            'toolbar_tablecontrols': {'type': 'Bool', 'default': True},
            'toolbar_link': {'type': 'Bool', 'default': True},
            'toolbar_unlink': {'type': 'Bool', 'default': True},
            'toolbar_anchor': {'type': 'Bool', 'default': True},
            'toolbar_image': {'type': 'Bool', 'default': True},
            'toolbar_media': {'type': 'Bool', 'default': False},
            'toolbar_charmap': {'type': 'Bool', 'default': False},
            'toolbar_hr': {'type': 'Bool', 'default': False},
            'toolbar_advhr': {'type': 'Bool', 'default': False},
            'toolbar_insertdate': {'type': 'Bool', 'default': False},
            'toolbar_inserttime': {'type': 'Bool', 'default': False},
            'toolbar_emotions': {'type': 'Bool', 'default': False},
            'toolbar_nonbreaking': {'type': 'Bool', 'default': False},
            'toolbar_pagebreak': {'type': 'Bool', 'default': False},
            'toolbar_print': {'type': 'Bool', 'default': False},
            'toolbar_preview': {'type': 'Bool', 'default': False},
            'toolbar_spellchecker': {'type': 'Bool', 'default': False},
            'toolbar_removeformat': {'type': 'Bool', 'default': False},
            'toolbar_cleanup': {'type': 'Bool', 'default': False},
            'toolbar_visualaid': {'type': 'Bool', 'default': False},
            'toolbar_visualchars': {'type': 'Bool', 'default': False},
            'toolbar_attribs': {'type': 'Bool', 'default': False},
            'toolbar_code': {'type': 'Bool', 'default': True},
            'toolbar_fullscreen': {'type': 'Bool', 'default': True},
            'customtoolbarbuttons': {'type': 'List', 'default': u''},
        },
        'resourcetypes': {
            'link_using_uids': {'type': 'Bool', 'default': False},
            'allow_captioned_images': {'type': 'Bool', 'default': False},
            'containsobjects': {'type': 'List', 'default': u'ATFolder\nATBTreeFolder\nPlone Site'},
            'containsanchors': {'type': 'List', 'default': u'ATEvent\nATNewsItem\nATDocument\nATRelativePathCriterion'},
            'linkable': {'type': 'List', 'default': u'ATTopic\nATEvent\nATFile\nATFolder\nATImage\nATBTreeFolder\nATNewsItem\nATDocument'},
            'imageobjects': {'type': 'List', 'default': u'ATImage'},
            'customplugins': {'type': 'List', 'default': u''},
            'entity_encoding': {'type': 'Text', 'default': u'raw'},
            'rooted': {'type': 'Bool', 'default': False},
        }
    }

    def _exportNode(self):
        """Export the object as a DOM node"""

        object = self._doc.createElement('object')

        # Loop through categories
        for key in self.attributes.keys():
            category = self.attributes[key]
            categorynode = self._doc.createElement(key)

            # Loop through fields in category
            for field in category.keys():
                fieldnode = self._doc.createElement(field)
                fieldvalue = getattr(self.context, field)

                if category[field]['type'] == 'Bool':
                    fieldnode.setAttribute('value', unicode(bool(fieldvalue)))
                elif category[field]['type'] == 'Text':

                    # Check for NoneType
                    if fieldvalue:
                        fieldnode.setAttribute('value', fieldvalue)
                    else:
                        fieldnode.setAttribute('value', '')
                elif category[field]['type'] == 'List':
                    if not fieldvalue:
                        fieldnode.setAttribute('value', '')
                    else:
                        for value in fieldvalue.split('\n'):
                            if value:
                                child = self._doc.createElement('element')
                                child.setAttribute('value', value)
                                fieldnode.appendChild(child)
                categorynode.appendChild(fieldnode)
            object.appendChild(categorynode)
        return object

    def _importNode(self, node):
        """Import the object from the DOM node"""
        if self.environ.shouldPurge() or node.getAttribute("purge").lower() == 'true':
            self._purgeAttributes()

        for categorynode in node.childNodes:
            if categorynode.nodeName != '#text' and categorynode.nodeName != '#comment':
                for fieldnode in categorynode.childNodes:
                    if fieldnode.nodeName != '#text' and fieldnode.nodeName != '#comment':
                        if self.attributes[categorynode.nodeName][fieldnode.nodeName]['type'] == 'Bool':
                            if fieldnode.hasAttribute('value'):
                                setattr(self.context, fieldnode.nodeName, self._convertToBoolean(fieldnode.getAttribute('value')))
                        elif self.attributes[categorynode.nodeName][fieldnode.nodeName]['type'] == 'Text':
                            if fieldnode.hasAttribute('value'):
                                setattr(self.context, fieldnode.nodeName, fieldnode.getAttribute('value'))
                        elif self.attributes[categorynode.nodeName][fieldnode.nodeName]['type'] == 'List':
                            field = getattr(self.context, fieldnode.nodeName)
                            if field is None or fieldnode.getAttribute("purge").lower() == 'true':
                                items = []
                            else:
                                items = field.split('\n')
                            for element in fieldnode.childNodes:
                                if element.nodeName != '#text' and element.nodeName != '#comment':
                                    if element.getAttribute('value') not in items:
                                        items.append(element.getAttribute('value'))
                            string = '\n'.join(items)
                            setattr(self.context, fieldnode.nodeName, string.decode())
        self._logger.info('TinyMCE Settings imported.')

    def _purgeAttributes(self):
        """Purge current attributes"""

        # Loop through categories
        for key in self.attributes.keys():
            category = self.attributes[key]

            # Loop through fields in category
            for field in category.keys():
                setattr(self.context, field, category[field]['default'])


def importTinyMCESettings(context):
    """Import TinyMCE Settings"""
    site = context.getSite()
    tool = getToolByName(site, 'portal_tinymce', None)
    if tool is None:
        return

    importObjects(tool, '', context)


def exportTinyMCESettings(context):
    """Export TinyMCE Settings"""
    site = context.getSite()
    tool = getToolByName(site, 'portal_tinymce', None)
    if tool is None:
        return

    exportObjects(tool, '', context)



from zope.interface import implements
from zope.i18nmessageid import MessageFactory
from zope.component import getMultiAdapter
from zope.formlib import form
from zope.event import notify

from plone.fieldsets.fieldsets import FormFieldsets
from plone.app.controlpanel.form import ControlPanelForm
from plone.app.controlpanel.events import ConfigurationChangedEvent
from plone.app.form.validators import null_validator
from plone.protect import CheckAuthenticator

from Products.CMFCore.utils import getToolByName
from Products.statusmessages.interfaces import IStatusMessage

from Products.TinyMCE.interfaces.utility import ITinyMCELayout
from Products.TinyMCE.interfaces.utility import ITinyMCEToolbar
from Products.TinyMCE.interfaces.utility import ITinyMCELibraries
from Products.TinyMCE.interfaces.utility import ITinyMCEResourceTypes

from Products.TinyMCE.browser.interfaces.controlpanel import ITinyMCEControlPanelForm
from Products.TinyMCE import TMCEMessageFactory as _
from Products.CMFPlone import PloneMessageFactory as __


class TinyMCEControlPanelForm(ControlPanelForm):
    """TinyMCE Control Panel Form"""
    implements(ITinyMCEControlPanelForm)

    tinymcelayout = FormFieldsets(ITinyMCELayout)
    tinymcelayout.id = 'tinymcelayout'
    tinymcelayout.label = _(u'Layout')

    tinymcetoolbar = FormFieldsets(ITinyMCEToolbar)
    tinymcetoolbar.id = 'tinymcetoolbar'
    tinymcetoolbar.label = _(u'Toolbar')

    tinymcelibraries = FormFieldsets(ITinyMCELibraries)
    tinymcelibraries.id = 'tinymcelibraries'
    tinymcelibraries.label = _(u'Libraries')

    tinymceresourcetypes = FormFieldsets(ITinyMCEResourceTypes)
    tinymceresourcetypes.id = 'tinymceresourcetypes'
    tinymceresourcetypes.label = _(u'Resource Types')

    form_fields = FormFieldsets(
                        tinymcelayout,
                        tinymcetoolbar,
                        tinymceresourcetypes,
                        tinymcelibraries
                        )

    label = _(u"TinyMCE Settings")
    description = _(u"Settings for the TinyMCE Wysiwyg editor.")
    form_name = _("TinyMCE Settings")

    @form.action(__(u'label_save', default=u'Save'), name=u'save')
    def handle_edit_action(self, action, data):
        CheckAuthenticator(self.request)
        if form.applyChanges(self.context, self.form_fields, data,
                             self.adapters):
            self.status = __("Changes saved.")
            notify(ConfigurationChangedEvent(self, data))
            self._on_save(data)
        else:
            self.status = __("No changes made.")

    @form.action(__(u'label_cancel', default=u'Cancel'),
                validator=null_validator,
                name=u'cancel')
    def handle_cancel_action(self, action, data):
        IStatusMessage(self.request).addStatusMessage(__("Changes canceled."),
                                                        type="info")
        portal = getToolByName(self.context, name='portal_url')\
            .getPortalObject()
        url = getMultiAdapter((portal, self.request),
                                name='absolute_url')()
        self.request.response.redirect(url + '/plone_control_panel')
        return ''



"""
This functionality is added to plone content types using adapters.
"""
import os

from zope.component import getUtility

from Products.TinyMCE.adapters.interfaces.JSONDetails import IJSONDetails
from Products.TinyMCE.adapters.interfaces.Save import ISave
from Products.TinyMCE.adapters.interfaces.JSONSearch import IJSONSearch
from Products.TinyMCE.adapters.interfaces.JSONFolderListing import IJSONFolderListing
from Products.TinyMCE.interfaces.utility import ITinyMCE
from Products.TinyMCE.tests.base import FunctionalTestCase


class AdaptersTestCase(FunctionalTestCase):

    def setUp(self):
        super(AdaptersTestCase, self).setUp()
        self.utility = getUtility(ITinyMCE)
        folder = self.portal.invokeFactory('Folder', id='folder')
        self.document = self.portal.invokeFactory('Document', id='document')
        self.folder_object = self.portal[folder]

    def test_json_details_document(self):
        # This class is used to get detail from a certain object. Let's create a Document.
        self.assertEqual(repr(self.portal[self.document]), '<ATDocument at /plone/document>')

        # The basic details should return the following.
        obj = IJSONDetails(self.portal[self.document])
        self.assertEqual(obj.getDetails(), '{"thumb": "", "description": "", "anchors": [], "title": "document"}')

        # Let's set some more details like description and body text.
        self.portal[self.document].setDescription('Test')
        self.portal[self.document].setText(u'<p><a name="anchor">anchor</a></p>', mimetype='text/html')

        # The details will now contain a bit more info.
        self.assertEqual(obj.getDetails(), '{"thumb": "", "description": "Test", "anchors": ["anchor"], "title": "document"}')

    def test_json_details_image(self):
        # We can also get the details of an image object.
        image = self.portal.invokeFactory('Image', id='image')
        self.assertEqual(repr(self.portal[image]), '<ATImage at /plone/image>')

        imgdata = open(os.path.join(os.path.dirname(__file__), 'sample.png'))
        self.portal[image].setImage(imgdata)

        # The details will now also include the thumbnail url and the imagescales.
        obj = IJSONDetails(self.portal[image])
        self.assertRegexpMatches(obj.getDetails(), r'\{"scales": \[\{"size": \[52, 43], "value": "", "title": "Original"}.+], "thumb": "http://nohost/plone/resolveuid/.*/@@images/image/thumb".+')

    def test_json_folder_listing(self):
        # The folder listing is used in the link and image drawers to show the contents
        # of a folder. Let's see what items our current siteroot has.

        linkableportal_types = self.utility.linkable.split('\n')
        linkableportal_types.extend(self.utility.containsobjects.split('\n'))
        object = IJSONFolderListing(self.portal)
        self.assertRegexpMatches(object.getListing(
            filter_portal_types=linkableportal_types,
            rooted=False,
            document_base_url='http://nohost/plone',
            upload_type='File',
        ), '\{"parent_url": "", "path": \[.+],.+"items": \[.+]}')

        # Let's create some more content to get breadcrumbs.
        document = self.folder_object.invokeFactory('Document', id='document')

        # When we call the getListing method on the document we should get the listing of
        # its parent.
        obj = IJSONFolderListing(self.folder_object.get(document))
        self.assertRegexpMatches(obj.getListing(
            filter_portal_types=[],
            rooted='False',
            document_base_url='http://nohost/plone/folder',
        ), '\{"parent_url": "http://nohost/plone".+}')

        # We can also select rooted so we don't get all the breadcrumbs.
        self.assertRegexpMatches(obj.getListing(
            filter_portal_types=[],
            rooted='True',
            document_base_url='http://nohost/plone/folder',
        ), '\{.*"path": \[{"url": "http://nohost/plone/folder".*}')

    def test_json_search(self):
        # Create an Event
        self.portal.invokeFactory('Event', id='events', title='Events')

        # The json search is used the look for content types within the self.portal. Let's see
        # if we can find some items containing the searchterm 'Events'
        linkable_portal_types = self.utility.linkable.split('\n')
        linkable_portal_types.extend(self.utility.containsobjects.split('\n'))

        obj = IJSONSearch(self.portal)
        self.assertRegexpMatches(
            obj.getSearchResults(filter_portal_types=linkable_portal_types,
            searchtext='Events',
        ), '\{.*"title": "Events", "url": "http://nohost/plone/events".*}')

    def test_json_save(self):
        # This class is used to save a document using json. Let's try and set some value.
        document = self.folder_object.invokeFactory('Document', id='document')
        obj = ISave(self.folder_object[document])
        obj.save(fieldname='text', text='<p>test</p>')

        # The document should now contain our new text.
        self.assertEqual(self.folder_object[self.document].getText(), '<p>test</p>')



import os

import transaction
from Products.CMFCore.utils import getToolByName
from plone.testing.z2 import Browser

from Products.TinyMCE.tests.base import IntegrationTestCase
from Products.TinyMCE.utility import form_adapter


class UtilityTestCase(IntegrationTestCase):

    def setUp(self):
        super(UtilityTestCase, self).setUp()
        self.utility = form_adapter(self.portal)

    def test_tinymce_configuration(self):
        # Let's get the configuration of TinyMCE and see if it returns a json structure.
        self.assertTrue(self.utility.getConfiguration(self.portal))

        # Now let's change some variables and see it still works.
        self.utility.toolbar_cut = True
        self.utility.toolbar_copy = True
        self.utility.toolbar_paste = True
        self.utility.toolbar_pastetext = True
        self.utility.toolbar_pasteword = True
        self.utility.toolbar_undo = True
        self.utility.toolbar_redo = True
        self.utility.toolbar_search = True
        self.utility.toolbar_replace = True
        self.utility.toolbar_underline = True
        self.utility.toolbar_strikethrough = True
        self.utility.toolbar_sub = True
        self.utility.toolbar_sup = True
        self.utility.toolbar_forecolor = True
        self.utility.toolbar_backcolor = True
        self.utility.toolbar_media = True
        self.utility.toolbar_charmap = True
        self.utility.toolbar_hr = True
        self.utility.toolbar_advhr = True
        self.utility.toolbar_insertdate = True
        self.utility.toolbar_inserttime = True
        self.utility.toolbar_emotions = True
        self.utility.toolbar_nonbreaking = True
        self.utility.toolbar_pagebreak = True
        self.utility.toolbar_print = True
        self.utility.toolbar_preview = True
        self.utility.toolbar_spellchecker = True
        self.utility.toolbar_removeformat = True
        self.utility.toolbar_cleanup = True
        self.utility.toolbar_visualaid = True
        self.utility.toolbar_visualchars = True
        self.utility.toolbar_attribs = True
        self.utility.resizing = False

        # The result should at least contain the new buttons we added.
        self.assertRegexpMatches(self.utility.getConfiguration(self.portal), '\{.+attribs.+}')

        # Let's change some more settings.
        self.utility.toolbar_external = True
        self.utility.autoresize = True
        self.utility.editor_width = u'100'
        self.utility.editor_height = u'abc'
        self.utility.toolbar_width = u'abc'
        self.utility.contextmenu = False
        self.utility.content_css = u'test.css'
        self.utility.link_using_uids = True
        self.utility.allow_captioned_images = True
        self.utility.rooted = True

        props = getToolByName(self, 'portal_properties')
        livesearch = props.site_properties.getProperty('enable_livesearch', False)
        livesearch = False
        livesearch  # pep8

        # The result should contain the settings specified.
        self.assertRegexpMatches(self.utility.getConfiguration(self.portal), '\{.+external.+}')

        # Let's call the portal_factory of a document and make sure the configuration
        # doesn't contain the save button:
        browser = Browser(self.app)
        self.app.acl_users.userFolderAddUser('root', 'secret', ['Manager'], [])
        transaction.commit()
        browser.addHeader('Authorization', 'Basic root:secret')
        browser.open('http://nohost/plone/createObject?type_name=Document')
        self.assertNotIn("&quot;save&quot;:", browser.contents)

        # Do some more toolbar tests, specifically testing the spellchecker button.
        # First, we make sure that no spellchecker is loaded when the toolbar button is
        # hidden.
        self.utility.toolbar_spellchecker = False
        transaction.commit()
        browser.open('http://nohost/plone/createObject?type_name=Document')

        # AtD shouldn't be there:
        self.assertNotIn("&quot;AtD&quot;", browser.contents)

        # Neither should iespell:
        self.assertNotIn("&quot;iespell&quot;", browser.contents)

        # Now, we enable the button and set AtD as the checker:
        self.utility.toolbar_spellchecker = True
        self.utility.libraries_spellchecker_choice = u'AtD'
        transaction.commit()
        browser.open('http://nohost/plone/createObject?type_name=Document')
        self.assertIn("&quot;AtD&quot;", browser.contents)

        # Now, we set iespell as the checker:
        self.utility.libraries_spellchecker_choice = u'iespell'
        transaction.commit()
        browser.open('http://nohost/plone/createObject?type_name=Document')
        self.assertIn("&quot;iespell&quot;", browser.contents)

        # When we have browser as the checker, neither iespell nor AtD should load:
        self.utility.libraries_spellchecker_choice = u'browser'
        transaction.commit()
        browser.open('http://nohost/plone/createObject?type_name=Document')
        self.assertNotIn("&quot;iespell&quot;", browser.contents)
        self.assertNotIn("&quot;AtD&quot;", browser.contents)

    def test_tinymce_configurable_image_dimensions(self):
        # The image scale dimensions being provided to the image chooser should be
        # gathered from the chosen AT content type. Let's begin by creating an
        # AT image:
        id = self.portal.invokeFactory('News Item', id='test')
        self.assertEqual(repr(self.portal[id]), '<ATNewsItem at /plone/test>')

        # Now the values being provided through JSON should be gotten from the ATNewsItem
        # schema:
        primary_field = self.portal.test.schema['image']
        scales = self.utility.getImageScales(primary_field)
        self.assertEqual(scales,
            [{'size': [0, 0], 'title': 'Original', 'value': ''},
            {'size': [16, 16], 'title': 'Listing', 'value': 'image_listing'},
            {'size': [32, 32], 'title': 'Icon', 'value': 'image_icon'},
            {'size': [64, 64], 'title': 'Tile', 'value': 'image_tile'},
            {'size': [128, 128], 'title': 'Thumb', 'value': 'image_thumb'},
            {'size': [200, 200], 'title': 'Mini', 'value': 'image_mini'},
            {'size': [400, 400], 'title': 'Preview', 'value': 'image_preview'},
            {'size': [768, 768], 'title': 'Large', 'value': 'image_large'}]
        )

        # If no primary field is given, we should get the scale dimensions from ATImage:
        scales = self.utility.getImageScales()
        self.assertEqual(scales,
            [{'size': [0, 0], 'title': 'Original', 'value': ''},
            {'size': [16, 16], 'title': 'Listing', 'value': 'image_listing'},
            {'size': [32, 32], 'title': 'Icon', 'value': 'image_icon'},
            {'size': [64, 64], 'title': 'Tile', 'value': 'image_tile'},
            {'size': [128, 128], 'title': 'Thumb', 'value': 'image_thumb'},
            {'size': [200, 200], 'title': 'Mini', 'value': 'image_mini'},
            {'size': [400, 400], 'title': 'Preview', 'value': 'image_preview'},
            {'size': [768, 768], 'title': 'Large', 'value': 'image_large'}]
        )

        # We need to specify a context, if we want the dimension of the original image
        imgdata = open(os.path.join(os.path.dirname(__file__), 'sample.png'))
        self.portal[id].setImage(imgdata)

        scales = self.utility.getImageScales(context=self.portal[id])
        self.assertEqual(scales,
            [{'size': [52, 43], 'title': 'Original', 'value': ''},
            {'size': [16, 16], 'title': 'Listing', 'value': 'image_listing'},
            {'size': [32, 32], 'title': 'Icon', 'value': 'image_icon'},
            {'size': [64, 64], 'title': 'Tile', 'value': 'image_tile'},
            {'size': [128, 128], 'title': 'Thumb', 'value': 'image_thumb'},
            {'size': [200, 200], 'title': 'Mini', 'value': 'image_mini'},
            {'size': [400, 400], 'title': 'Preview', 'value': 'image_preview'},
            {'size': [768, 768], 'title': 'Large', 'value': 'image_large'}]
        )



from zope.component import getUtility
from Products.CMFCore.utils import getToolByName

from Products.TinyMCE.upgrades import upgrade_10_to_11
from Products.TinyMCE.interfaces.utility import ITinyMCE
from Products.TinyMCE.tests.base import FunctionalTestCase


class UpgradesTestCase(FunctionalTestCase):

    def test_upgrade_profile(self):
        # First set the entity encoding to a different value.
        tinymce = getUtility(ITinyMCE)
        tinymce.entity_encoding = u"named"

        # Then run the upgrade from 1.0. to 1.1.
        portal_setup = getToolByName(self.portal, 'portal_setup')
        upgrade_10_to_11(portal_setup)

        # And check the outcome
        self.assertEqual(tinymce.entity_encoding, u'raw')



from zope.component import getUtility

from Products.CMFPlone.tests import dummy
from Products.TinyMCE.interfaces.utility import ITinyMCE
from Products.TinyMCE.tests.base import FunctionalTestCase


class TransformsTestCase(FunctionalTestCase):

        # Tests integration with plone.outputfilters, which provides 2 filters that are
        # applied while rendering rich text:

        # * Resolving UID links to absolute URIs.
        # * Adding captions to images with the "captioned" CSS class.

        # These filters used to be implemented in Products.TinyMCE, so for backwards
        # compatibility they can be enabled via settings in the TinyMCE control panel.

    def test_filters(self):
        # Let's turn these filters on first.
        tinymce_utility = getUtility(ITinyMCE)
        tinymce_utility.link_using_uids = True
        tinymce_utility.allow_captioned_images = True

        # To test the settings, we'll need an image.
        self.portal.invokeFactory('Image', id='image.jpg', title="Image", file=dummy.Image())
        image = getattr(self.portal, 'image.jpg')
        image.setDescription('My caption')
        image.reindexObject()
        UID = image.UID()

        # Let's transform some text/html to text/x-html-safe, which should trigger the
        # filters.
        text = """
<html>
   <head></head>
   <body>
       <img src="resolveuid/%s/image_thumb" class="image-left captioned" width="200" alt="My alt text" />
       <p><img src="/image.jpg" class="image-right captioned" width="200" style="border-width:1px" /></p>
       <pre>This is line 1
             This is line 2</pre>
   </body>
</html>""" % UID
        transformed_text = self.portal.portal_transforms.convertTo('text/x-html-safe', text, mimetype='text/html', context=self.portal)

        # The UID reference should be converted to an absolute url, and a caption should be added.
        self.assertEqual(unicode(transformed_text).replace(' ', ''), u"""
<dl style="width:200px;" class="image-left captioned">
<dt><img src="http://nohost/plone/image.jpg/image_thumb" alt="My alt text" title="Image" height="16" width="200" /></dt>
 <dd class="image-caption" style="width:200px;">My caption</dd>
</dl>
<p><dl style="width:200px;" class="image-right captioned">
<dt><img src="http://nohost/plone/image.jpg/image" alt="Image" title="Image" height="16" width="200" style="border-width:1px" /></dt>
 <dd class="image-caption" style="width:200px;">My caption</dd>
</dl></p>
<pre>This is line 1
      This is line 2</pre>
""".replace(' ', ''))
        # Now turn off the settings.
        tinymce_utility.link_using_uids = False
        tinymce_utility.allow_captioned_images = False

        # Now the filters should not be applied.
        transformed_text_2 = self.portal.portal_transforms.convertTo('text/x-html-safe', text, mimetype='text/html', context=self.portal)
        self.assertNotEqual(unicode(transformed_text_2).replace(' ', ''), unicode(transformed_text).replace(' ', ''))



from zope.component import queryUtility
from zope.component import getUtility
from Products.CMFCore.interfaces import IPropertiesTool

from Products.TinyMCE.interfaces.utility import ITinyMCE
from Products.TinyMCE.tests.base import FunctionalTestCase
from Products.TinyMCE.setuphandlers import remove_editor
from Products.TinyMCE.setuphandlers import add_editor
from Products.TinyMCE.setuphandlers import unregisterUtility


class SetupHandlersTestCase(FunctionalTestCase):

    def test_remove_editor(self):
        # First let's remove the editor
        remove_editor(self.portal)

        # Check if it is removed.

        portal_props = getUtility(IPropertiesTool)
        site_props = getattr(portal_props, 'site_properties', None)
        attrname = 'available_editors'
        editors = list(site_props.getProperty(attrname))
        self.assertNotIn('TinyMCE', editors)

        # And now add the editor.
        add_editor(self.portal)

        # And check if it is added.
        editors = list(site_props.getProperty(attrname))
        self.assertIn('TinyMCE', editors)

    def test_unregister_utility(self):
        unregisterUtility(self.portal)

        # And check if the utility is removed.
        self.assertEqual(queryUtility(ITinyMCE, default='Not found'), 'Not found')



import transaction
from plone.testing.z2 import Browser

from Products.TinyMCE.tests.base import FunctionalTestCase
from plone.app.testing import TEST_USER_NAME
from plone.app.testing import TEST_USER_ID
from plone.app.testing import TEST_USER_PASSWORD
from plone.app.testing import setRoles


class ControlpanelTestCase(FunctionalTestCase):
    """ Test the fix for Ticket #12212  """

    def setUp(self):
        super(ControlpanelTestCase, self).setUp()
        # we need to be a Manager
        setRoles(self.portal, TEST_USER_ID, ['Manager'])
        transaction.commit()

    def test_cancel_button(self):
        browser = Browser(self.portal)
        portal_url = self.portal.absolute_url()

        # Get an account and login via the login form.
        browser.open(portal_url + '/login_form')
        browser.getControl(name='__ac_name').value = TEST_USER_NAME
        browser.getControl(name='__ac_password').value = TEST_USER_PASSWORD
        browser.getControl(name='submit').click()

        # click the cancel button. Without the fix for #12212
        browser.open(portal_url + '/portal_tinymce/@@tinymce-controlpanel')
        browser.getControl(name='form.actions.cancel').click()
        self.failUnless('<dd>Changes canceled.</dd>' in browser.contents)
        self.assertEquals(browser.url,
            'http://nohost/plone/plone_control_panel')

    def test_save_button(self):
        browser = Browser(self.portal)
        portal_url = self.portal.absolute_url()

        browser.open(portal_url + '/login_form')
        browser.getControl(name='__ac_name').value = TEST_USER_NAME
        browser.getControl(name='__ac_password').value = TEST_USER_PASSWORD
        browser.getControl(name='submit').click()

        # click the save button. Because of the fix for #12212 we had to
        # extend the controlpanel form by own buttons
        browser.open(portal_url + '/portal_tinymce/@@tinymce-controlpanel')
        browser.getControl(name='form.contextmenu').value = False
        browser.getControl(name='form.actions.save').click()

        self.failUnless('<dd>Changes saved.</dd>' in browser.contents)
        self.assertEquals(browser.url,
            'http://nohost/plone/portal_tinymce/@@tinymce-controlpanel')
